Module create

Module create 

Creates a load balancer.

This operation provisions a new load balancer by using the configuration that you define in the request object. After the API validates the request and starts the provisioning process, the API returns a response object that contains a unique ID and the status of provisioning the load balancer.

In the response, the load balancer provisioning status is ACTIVE, PENDING_CREATE, or ERROR.

If the status is PENDING_CREATE, issue GET /v2/lbaas/loadbalancers/{loadbalancer_id} to view the progress of the provisioning operation. When the load balancer status changes to ACTIVE, the load balancer is successfully provisioned and is ready for further configuration.

If the API cannot fulfill the request due to insufficient data or data that is not valid, the service returns the HTTP Bad Request (400) response code with information about the failure in the response body. Validation errors require that you correct the error and submit the request again.

Administrative users can specify a project ID that is different than their own to create load balancers for other projects.

An optional flavor_id attribute can be used to create the load balancer using a pre-configured octavia flavor. Flavors are created by the operator to allow custom load balancer configurations, such as allocating more memory for the load balancer.

An optional vip_qos_policy_id attribute from Neutron can be used to apply QoS policies on a loadbalancer VIP, also could pass a ‘null’ value to remove QoS policies.

You can also specify the provider attribute when you create a load balancer. The provider attribute specifies which backend should be used to create the load balancer. This could be the default provider (octavia) or a vendor supplied provider if one has been installed. Setting both a flavor_id and a provider will result in a conflict error if the provider does not match the provider of the configured flavor profiles.

Specifying a Virtual IP (VIP) is mandatory. There are three ways to specify a VIP network for the load balancer:

Additional VIPs may also be specified in the additional_vips field, by providing a list of JSON objects containing a subnet_id and optionally an ip_address. All additional subnets must be part of the same network as the primary VIP.

An optional vip_sg_ids attribute can be used to set custom Neutron Security Groups that are applied on the VIP port of the Load Balancer. When this option is used, Octavia does not manage the security of the Listeners, the user must set Security Group Rules to allow the network traffic on the VIP port. vip_sg_ids are incompatible with SR-IOV load balancer and cannot be set if the load balancer has a listener that uses allowed_cidrs.

Structs

AdditionalVips
Type for additional vips
AdditionalVipsBuilder
Builder for AdditionalVips.
DefaultPool
Defines mandatory and optional attributes of a POST request.
DefaultPoolBuilder
Builder for DefaultPool.
Healthmonitor
Defines mandatory and optional attributes of a POST request.
HealthmonitorBuilder
Builder for Healthmonitor.
L7policies
Defines mandatory and optional attributes of a POST request.
L7policiesBuilder
Builder for L7policies.
Listeners
Defines mandatory and optional attributes of a POST request.
ListenersBuilder
Builder for Listeners.
Loadbalancer
A load balancer object.
LoadbalancerBuilder
Builder for Loadbalancer.
Members
Defines mandatory and optional attributes of a POST request.
MembersBuilder
Builder for Members.
Pools
Defines mandatory and optional attributes of a POST request.
PoolsBuilder
Builder for Pools.
PoolsHealthmonitor
Defines mandatory and optional attributes of a POST request.
PoolsHealthmonitorBuilder
Builder for PoolsHealthmonitor.
RedirectPool
Defines mandatory and optional attributes of a POST request.
RedirectPoolBuilder
Builder for RedirectPool.
RedirectPoolHealthmonitor
Defines mandatory and optional attributes of a POST request.
RedirectPoolHealthmonitorBuilder
Builder for RedirectPoolHealthmonitor.
Request
RequestBuilder
Builder for Request.
Rules
Defines mandatory and optional attributes of a POST request.
RulesBuilder
Builder for Rules.
SessionPersistence
Defines mandatory and optional attributes of a POST request.
SessionPersistenceBuilder
Builder for SessionPersistence.

Enums

Action
AdditionalVipsBuilderError
Error type for AdditionalVipsBuilder
ClientAuthentication
CompareType
DefaultPoolBuilderError
Error type for DefaultPoolBuilder
DefaultPoolProtocol
HealthmonitorBuilderError
Error type for HealthmonitorBuilder
HealthmonitorType
HttpMethod
L7policiesBuilderError
Error type for L7policiesBuilder
LbAlgorithm
ListenersBuilderError
Error type for ListenersBuilder
ListenersProtocol
LoadbalancerBuilderError
Error type for LoadbalancerBuilder
MembersBuilderError
Error type for MembersBuilder
PoolsBuilderError
Error type for PoolsBuilder
PoolsHealthmonitorBuilderError
Error type for PoolsHealthmonitorBuilder
PoolsHealthmonitorType
PoolsProtocol
RedirectPoolBuilderError
Error type for RedirectPoolBuilder
RedirectPoolHealthmonitorBuilderError
Error type for RedirectPoolHealthmonitorBuilder
RedirectPoolHealthmonitorType
RedirectPoolProtocol
RequestBuilderError
Error type for RequestBuilder
RulesBuilderError
Error type for RulesBuilder
RulesType
SessionPersistenceBuilderError
Error type for SessionPersistenceBuilder
SessionPersistenceType
Type