pub struct RequestBuilder<'a> { /* private fields */ }Expand description
Builder for Request.
Implementations
Sourceimpl<'a> RequestBuilder<'a>
impl<'a> RequestBuilder<'a>
Sourcepub fn availability_zone<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn availability_zone<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
An availability zone name.
Sourcepub fn created_at<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn created_at<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The UTC date and timestamp when the resource was created.
Sourcepub fn description<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn description<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
A human-readable description for the resource.
Sourcepub fn flavor_id<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn flavor_id<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The ID of the flavor.
Sourcepub fn id<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn id<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
The ID of the resource
Sourcepub fn marker<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn marker<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
ID of the last item in the previous list
Sourcepub fn name<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn name<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
Human-readable name of the resource.
Return the list of entities that do not have one or more of the given tags.
Return the list of entities that do not have at least one of the given tags.
Sourcepub fn operating_status<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn operating_status<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The operating status of the resource.
Sourcepub fn page_reverse(&mut self, value: bool) -> &mut Self
pub fn page_reverse(&mut self, value: bool) -> &mut Self
The page direction.
Sourcepub fn project_id<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn project_id<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The ID of the project owning this resource.
Sourcepub fn provider<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn provider<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
Provider name for the load balancer.
Sourcepub fn provisioning_status<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn provisioning_status<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The provisioning status of the resource.
Return the list of entities that have this tag or tags.
Return the list of entities that have one or more of the given tags.
Sourcepub fn updated_at<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn updated_at<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The UTC date and timestamp when the resource was last updated.
Sourcepub fn vip_address<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn vip_address<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The IP address of the Virtual IP (VIP).
Sourcepub fn vip_network_id<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn vip_network_id<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The ID of the network for the Virtual IP (VIP).
Sourcepub fn vip_port_id<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn vip_port_id<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The ID of the Virtual IP (VIP) port.
Sourcepub fn vip_qos_policy_id<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn vip_qos_policy_id<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The ID of the QoS Policy which will apply to the Virtual IP (VIP).
Sourcepub fn vip_subnet_id<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn vip_subnet_id<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The ID of the subnet for the Virtual IP (VIP).