Module delete

Module delete 

Removes a pool and its associated configuration from the load balancer.

The API immediately purges any and all configuration data, depending on the configuration settings. You cannot recover it.

Structs

Request
RequestBuilder
Builder for Request.

Enums

RequestBuilderError
Error type for RequestBuilder