Module get

Module get 

Shows the details of a pool.

If you are not an administrative user and the parent load balancer does not belong to your project, the service returns the HTTP Forbidden (403) response code.

This operation does not require a request body.

Structs

Request
RequestBuilder
Builder for Request.

Enums

RequestBuilderError
Error type for RequestBuilder