pub struct RequestBuilder<'a> { /* private fields */ }Expand description
Builder for Request.
Implementations
Sourceimpl<'a> RequestBuilder<'a>
impl<'a> RequestBuilder<'a>
Sourcepub fn admin_state_up(&mut self, value: bool) -> &mut Self
pub fn admin_state_up(&mut self, value: bool) -> &mut Self
The administrative state of the resource
Sourcepub fn alpn_protocols<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn alpn_protocols<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
A list of ALPN protocols. Available protocols: http/1.0, http/1.1, h2
Sourcepub fn created_at<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn created_at<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The UTC date and timestamp when the resource was created.
Sourcepub fn description<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn description<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
A human-readable description for the resource.
Sourcepub fn id<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn id<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
The ID of the resource
Sourcepub fn loadbalancer_id<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn loadbalancer_id<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The ID of the load balancer for the pool.
Sourcepub fn marker<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn marker<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
ID of the last item in the previous list
Sourcepub fn name<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn name<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
Human-readable name of the resource.
Return the list of entities that do not have one or more of the given tags.
Return the list of entities that do not have at least one of the given tags.
Sourcepub fn operating_status<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn operating_status<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The operating status of the resource.
Sourcepub fn page_reverse(&mut self, value: bool) -> &mut Self
pub fn page_reverse(&mut self, value: bool) -> &mut Self
The page direction.
Sourcepub fn project_id<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn project_id<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The ID of the project owning this resource.
Sourcepub fn provisioning_status<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn provisioning_status<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The provisioning status of the resource.
Return the list of entities that have this tag or tags.
Return the list of entities that have one or more of the given tags.
Sourcepub fn tls_ciphers<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn tls_ciphers<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
List of ciphers in OpenSSL format
pub fn tls_enabled(&mut self, value: bool) -> &mut Self
Sourcepub fn tls_versions<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn tls_versions<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
A list of TLS protocol versions.
Sourcepub fn updated_at<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn updated_at<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The UTC date and timestamp when the resource was last updated.