pub struct RequestBuilder<'a> { /* private fields */ }Expand description
Builder for Request.
Implementations
Sourceimpl<'a> RequestBuilder<'a>
impl<'a> RequestBuilder<'a>
Sourcepub fn address<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn address<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
The IP address of the backend member server.
Sourcepub fn admin_state_up(&mut self, value: bool) -> &mut Self
pub fn admin_state_up(&mut self, value: bool) -> &mut Self
The administrative state of the resource
Sourcepub fn created_at<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn created_at<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The UTC date and timestamp when the resource was created.
Sourcepub fn description<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn description<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
A human-readable description for the resource.
Sourcepub fn id<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn id<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
The ID of the resource
Sourcepub fn marker<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn marker<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
ID of the last item in the previous list
Sourcepub fn monitor_address<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn monitor_address<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
An alternate IP address used for health monitoring a backend member.
Sourcepub fn monitor_port<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn monitor_port<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
An alternate protocol port used for health monitoring a backend member.
Sourcepub fn name<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn name<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
Human-readable name of the resource.
Return the list of entities that do not have one or more of the given tags.
Return the list of entities that do not have at least one of the given tags.
Sourcepub fn operating_status<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn operating_status<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The operating status of the resource.
Sourcepub fn page_reverse(&mut self, value: bool) -> &mut Self
pub fn page_reverse(&mut self, value: bool) -> &mut Self
The page direction.
Sourcepub fn pool_id<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn pool_id<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pool_id parameter for /v2/lbaas/pools/{pool_id}/members/{member_id} API
Sourcepub fn project_id<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn project_id<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The ID of the project owning this resource.
Sourcepub fn protocol_port(&mut self, value: i32) -> &mut Self
pub fn protocol_port(&mut self, value: i32) -> &mut Self
The protocol port number the backend member server is listening on.
Sourcepub fn provisioning_status<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn provisioning_status<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The provisioning status of the resource.
Sourcepub fn subnet_id<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn subnet_id<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The subnet ID the member service is accessible from.
Return the list of entities that have this tag or tags.
Return the list of entities that have one or more of the given tags.
Sourcepub fn updated_at<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn updated_at<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The UTC date and timestamp when the resource was last updated.