Module set

Module set 

Update an existing pool.

If the request is valid, the service returns the Accepted (202) response code. To confirm the update, check that the pool provisioning status is ACTIVE. If the status is PENDING_UPDATE, use a GET operation to poll the pool object for changes.

This operation returns the updated pool object with the ACTIVE, PENDING_UPDATE, or ERROR provisioning status.

Structs

Pool
Defines attributes that are acceptable of a PUT request.
PoolBuilder
Builder for Pool.
Request
RequestBuilder
Builder for Request.
SessionPersistence
A JSON object specifying the session persistence for the pool or null for no session persistence. See Pool Session Persistence. Default is null.
SessionPersistenceBuilder
Builder for SessionPersistence.

Enums

LbAlgorithm
PoolBuilderError
Error type for PoolBuilder
RequestBuilderError
Error type for RequestBuilder
SessionPersistenceBuilderError
Error type for SessionPersistenceBuilder
Type