Lists all pools for the project.
Use the fields query parameter to control which fields are returned in
the response body. Additionally, you can filter results by using query
string parameters. For information, see
Filtering and column selection.
Administrative users can specify a project ID that is different than their own to list pools for other projects.
The list might be empty.
Structs
- Request
- Request
Builder - Builder for
Request.
Enums
- Request
Builder Error - Error type for RequestBuilder