Update an existing pool.
If the request is valid, the service returns the Accepted (202) response
code. To confirm the update, check that the pool provisioning status is
ACTIVE. If the status is PENDING_UPDATE, use a GET operation to poll
the pool object for changes.
This operation returns the updated pool object with the ACTIVE,
PENDING_UPDATE, or ERROR provisioning status.
Structs
- Pool
- Defines attributes that are acceptable of a PUT request.
- Pool
Builder - Builder for
Pool. - Request
- Request
Builder - Builder for
Request. - Session
Persistence - A JSON object specifying the session persistence for the pool or
nullfor no session persistence. See Pool Session Persistence. Default isnull. - Session
Persistence Builder - Builder for
SessionPersistence.
Enums
- LbAlgorithm
- Pool
Builder Error - Error type for PoolBuilder
- Request
Builder Error - Error type for RequestBuilder
- Session
Persistence Builder Error - Error type for SessionPersistenceBuilder
- Type